@@ -1,8 +1,15 @@
-from ast import Assign, Constant, Import, ImportFrom, List, Module, Name, Str
+import sys
+from ast import Assign, Constant, Import, ImportFrom, List, Module, Name, Str, Tuple
 from enum import IntEnum
 from functools import total_ordering
 
-from stdlib_list import in_stdlib
+
+try:
+    from importlib.metadata import version
+except ImportError:
+    from importlib_metadata import version
+
+ver = version("flake8-alphabetize")
 
 
 class AlphabetizeException(Exception):
@@ -54,6 +61,16 @@ class NodeTypeEnum(IntEnum):
     IMPORT_FROM = 2
 
 
+def _is_in_stdlib(name):
+    if hasattr(sys, "stdlib_module_names"):
+        main_package = name.split(".")[0]
+        return main_package in sys.stdlib_module_names
+    else:
+        from stdlib_list import in_stdlib
+
+        return in_stdlib(name)
+
+
 @total_ordering
 class AzImport:
     def __init__(self, app_names, ast_node):
@@ -65,8 +82,6 @@ class AzImport:
         if isinstance(ast_node, Import):
             self.node_type = NodeTypeEnum.IMPORT
             names = ast_node.names
-            if len(names) != 1:
-                return
 
             self.module_name = names[0].name
             level = 0
@@ -93,7 +108,7 @@ class AzImport:
 
         if self.module_name == "__future__":
             group = GroupEnum.FUTURE
-        elif in_stdlib(self.module_name):
+        elif _is_in_stdlib(self.module_name):
             group = GroupEnum.STDLIB
         elif level > 0:
             group = GroupEnum.APPLICATION
@@ -157,7 +172,7 @@ def _find_nodes(tree):
                     if isinstance(t, Name) and t.id == "__all__":
                         value = n.value
 
-                        if isinstance(value, List):
+                        if isinstance(value, (List, Tuple)):
                             list_node = value
 
     return import_nodes, list_node
@@ -187,14 +202,19 @@ def _find_dunder_all_error(node):
 
 def _find_errors(app_names, tree):
     import_nodes, list_node = _find_nodes(tree)
-    imports = [AzImport(app_names, imp) for imp in import_nodes]
-
     errors = []
 
     dunder_all_error = _find_dunder_all_error(list_node)
     if dunder_all_error is not None:
         errors.append(dunder_all_error)
 
+    imports = []
+    for imp in import_nodes:
+        if isinstance(imp, Import) and len(imp.names) > 1:
+            return errors
+        else:
+            imports.append(AzImport(app_names, imp))
+
     len_imports = len(imports)
     if len_imports == 0:
         return errors
